@@ -11,26 +11,46 @@ from kodexa.model import Document
 from kodexa.pipeline import PipelineContext
 from kodexa.stores import TableDataStore
 
-logger = logging.getLogger('kodexa.cloud')
+logger = logging.getLogger('kodexa.platform')
 
 
-class KodexaCloudSession:
+class KodexaPlatform:
+
+    @staticmethod
+    def get_access_token():
+        return os.getenv('KODEXA_ACCESS_TOKEN')
+
+    @staticmethod
+    def get_url():
+        return os.getenv('KODEXA_URL', "https://platform.kodexa.com")
+
+    @staticmethod
+    def set_access_token(access_token):
+        os.environ["KODEXA_ACCESS_TOKEN"] = access_token
+
+    @staticmethod
+    def set_url(url):
+        os.environ["KODEXA_URL"] = url
+
+
+class KodexaSession:
     """
-    A Session on the Kodexa Cloud for leveraging pipelines and services
+    A Session on the Kodexa platform for leveraging pipelines and services
     """
 
-    def __init__(self, session_type, slug, access_token=None, cloud_url='https://cloud.kodexa.com'):
-        self.access_token = access_token if access_token else os.getenv('KODEXA_ACCESS_TOKEN')
+    def __init__(self, session_type, slug):
         self.session_type = session_type
-        self.cloud_url = cloud_url
         self.slug = slug
         self.cloud_session = None
 
     def start(self):
-        r = requests.post(f"{self.cloud_url}/api/sessions", params={self.session_type: self.slug},
-                          headers={"x-access-token": self.access_token})
+        logger.info(f"Creating session {self.slug} ({KodexaPlatform.get_url()})")
+        r = requests.post(f"{KodexaPlatform.get_url()}/api/sessions", params={self.session_type: self.slug},
+                          headers={"x-access-token": KodexaPlatform.get_access_token()})
 
         if r.status_code != 200:
+            logger.error("Unable to create session")
+            logger.error(r.text)
             raise Exception("Unable to create a session, check your URL and access token")
         self.cloud_session = Dict(json.loads(r.text))
 
@@ -43,10 +63,10 @@ class KodexaCloudSession:
 
         data = {"options": json.dumps(options)}
 
-        r = requests.post(f"{self.cloud_url}/api/sessions/{self.cloud_session.id}/execute",
+        r = requests.post(f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/execute",
                           params={self.session_type: self.slug},
                           data=data,
-                          headers={"x-access-token": self.access_token}, files=files)
+                          headers={"x-access-token": KodexaPlatform.get_access_token()}, files=files)
         execution = Dict(json.loads(r.text))
         return execution
 
@@ -54,8 +74,9 @@ class KodexaCloudSession:
 
         status = execution.status
         while execution.status == "PENDING" or execution.status == "RUNNING":
-            r = requests.get(f"{self.cloud_url}/api/sessions/{self.cloud_session.id}/executions/{execution.id}",
-                             headers={"x-access-token": self.access_token})
+            r = requests.get(
+                f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/executions/{execution.id}",
+                headers={"x-access-token": KodexaPlatform.get_access_token()})
             execution = Dict(json.loads(r.text))
             if status != execution.status:
                 logger.info(f"Status changed from {status} -> {execution.status}")
@@ -72,31 +93,31 @@ class KodexaCloudSession:
     def get_output_document(self, execution):
         if execution.outputId:
             doc = requests.get(
-                f"{self.cloud_url}/api/sessions/{self.cloud_session.id}/executions/{execution.id}/objects/{execution.outputId}",
-                headers={"x-access-token": self.access_token})
+                f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/executions/{execution.id}/objects/{execution.outputId}",
+                headers={"x-access-token": KodexaPlatform.get_access_token()})
             return Document.from_msgpack(doc.content)
         else:
             return None
 
     def get_store(self, execution, store):
         response = requests.get(
-            f"{self.cloud_url}/api/sessions/{self.cloud_session.id}/executions/{execution.id}/stores/{store.id}",
-            headers={"x-access-token": self.access_token})
+            f"{KodexaPlatform.get_url()}/api/sessions/{self.cloud_session.id}/executions/{execution.id}/stores/{store.id}",
+            headers={"x-access-token": KodexaPlatform.get_access_token()})
+        logger.debug(f"Response from server [{response.text}]")
         raw_store = Dict(json.loads(response.text))
-        return TableDataStore(raw_store.columns, raw_store.rows)
+        return TableDataStore(raw_store.data.columns, raw_store.data.rows)
 
     def merge_stores(self, execution, context):
         for store in execution.stores:
             context.add_store(store.name, self.get_store(execution, store))
 
 
-class KodexaCloudPipeline:
+class KodexaPipeline:
     """
-    Allow you to interact with a pipeline that has been deployed in the Kodexa Cloud
+    Allow you to interact with a pipeline that has been deployed in the Kodexa platform
     """
 
-    def __init__(self, slug, version=None, attach_source=True, options=None, auth=None,
-                 cloud_url='https://cloud.kodexa.com', access_token=None):
+    def __init__(self, slug, version=None, attach_source=True, options=None, auth=None):
         if auth is None:
             auth = []
         if options is None:
@@ -106,11 +127,9 @@ class KodexaCloudPipeline:
         self.attach_source = attach_source
         self.options = options
         self.auth = auth
-        self.cloud_url = cloud_url
-        self.access_token = access_token
 
     def execute(self, input):
-        cloud_session = KodexaCloudSession("pipeline", self.slug, self.access_token, self.cloud_url)
+        cloud_session = KodexaSession("pipeline", self.slug)
         cloud_session.start()
 
         if isinstance(input, Document):
@@ -129,26 +148,31 @@ class KodexaCloudPipeline:
         return context
 
 
-class KodexaCloudService:
+class KodexaAction:
     """
-    Allows you to interact with a content service that has been deployed in the Kodexa cloud
+    Allows you to interact with an action that has been deployed in the Kodexa platform
     """
 
-    def __init__(self, slug, version=None, attach_source=False, options={}, auth=[],
-                 cloud_url='https://cloud.kodexa.com', access_token=None):
+    def __init__(self, slug, version=None, attach_source=False, options=None, auth=None):
+        if auth is None:
+            auth = []
+        if options is None:
+            options = {}
         self.slug = slug
         self.version = version
         self.attach_source = attach_source
         self.options = options
         self.auth = auth
-        self.cloud_url = cloud_url
-        self.access_token = access_token
+
+    def to_yaml(self):
+        # TODO needs implementation
+        config = {}
 
     def get_name(self):
         return f"Kodexa Service ({self.slug})"
 
     def process(self, document, context):
-        cloud_session = KodexaCloudSession("service", self.slug, self.access_token, self.cloud_url)
+        cloud_session = KodexaSession("service", self.slug)
         cloud_session.start()
         execution = cloud_session.execute_service(document, self.options, self.attach_source)
         execution = cloud_session.wait_for_execution(execution)
