@@ -89,7 +89,7 @@ class ContentNode(object):
             >>> current_content_node.to_dict()
         """
         new_dict = {'type': self.type, 'content': self.content, 'content_parts': self.content_parts, 'features': [],
-                    'index': self.index, 'children': []}
+                    'index': self.index, 'children': [], 'uuid': self.uuid}
         for feature in self.get_features():
             new_dict['features'].append(feature.to_dict())
 
@@ -101,6 +101,8 @@ class ContentNode(object):
     def from_dict(document, content_node_dict):
         new_content_node = document.create_node(type=content_node_dict['type'], content=content_node_dict[
             'content'] if 'content' in content_node_dict else None)
+        if 'uuid' in content_node_dict:
+            new_content_node.uuid = content_node_dict['uuid']
 
         if 'content_parts' in content_node_dict:
             new_content_node.content_parts = content_node_dict['content_parts']
@@ -281,7 +283,7 @@ class ContentNode(object):
         """
         return self.type
 
-    def select(self, selector):
+    def select(self, selector, variables=None):
         """
         Execute a selector on this node and then return a list of the matching nodes
 
@@ -289,11 +291,14 @@ class ContentNode(object):
            [ContentNode]
 
         :param selector: The selector (ie. //*)
+        :param variables: A dictionary of variable name/value to use in substituion
         :return: A list of the matching content nodes
         """
+        if variables is None:
+            variables = {}
         from kodexa.selectors import parse
         parsed_selector = parse(selector)
-        return parsed_selector.resolve(self)
+        return parsed_selector.resolve(self, variables)
 
     def get_all_content(self, separator=" "):
         """
@@ -440,33 +445,35 @@ class ContentNode(object):
         :param data: Attach the a dictionary of data for the given tag
         """
 
+        if content_re:
+            pattern = re.compile(content_re)
+
         for node in self.select(selector):
             if fixed_position:
-                self.add_feature('tag', tag_to_apply,
+                node.add_feature('tag', tag_to_apply,
                                  Tag(fixed_position[0], fixed_position[1],
-                                     self.content[fixed_position[0]:fixed_position[1]],
+                                     node.content[fixed_position[0]:fixed_position[1]],
                                      data))
             else:
                 if not content_re:
-                    self.add_feature('tag', tag_to_apply, Tag(data=data))
+                    node.add_feature('tag', tag_to_apply, Tag(data=data))
                 else:
-                    pattern = re.compile(content_re)
                     if not use_all_content:
-                        if self.content:
-                            content = self.content
+                        if node.content:
+                            content = node.content
                         else:
                             return
                     else:
-                        content = self.get_all_content()
+                        content = node.get_all_content()
 
                     match = pattern.match(content)
                     if match:
                         if node_only:
-                            self.add_feature('tag', tag_to_apply, Tag(data=data))
+                            node.add_feature('tag', tag_to_apply, Tag(data=data))
                         else:
                             for index, m in enumerate(match.groups()):
                                 idx = index + 1
-                                self.add_feature('tag', tag_to_apply,
+                                node.add_feature('tag', tag_to_apply,
                                                  Tag(match.start(idx), match.end(idx), match.group(idx), data=data))
 
     def get_tags(self):
@@ -788,12 +795,18 @@ class Document(object):
         :return: A list of the matching content nodes
         """
         if self.content_node:
-            return self.content_node.select(selector)
+            result = self.content_node.select(selector)
+            if isinstance(result, list):
+                return result
+            else:
+                return [self.content_node] if bool(result) else []
         else:
             return []
 
 
 class KodexaRender:
+    KODEXA_JS_URL = 'https://cdn.jsdelivr.net/npm/kodexajs/kodexa'
+
     """
     An implementation of a render that uses the KodexaJS
     library to render the document
@@ -812,7 +825,7 @@ class KodexaRender:
 
 require.config({
     paths: {
-        'kodexa-lib-""" + render_uuid + """': 'https://cdn.jsdelivr.net/npm/kodexajs/kodexa',
+        'kodexa-lib-""" + render_uuid + """': '""" + KodexaRender.KODEXA_JS_URL + """',
         'jquery': '//ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min'
     }
 });
